@@ -17,6 +17,7 @@ COMPANY_CIK_NAME_QUERY = '''
         }
     }'''
 
+
 DATASET_QUERY = lambda name, api_key : '''
     query {
         dataset(name:"%s","%s"){
@@ -31,9 +32,29 @@ DATASET_QUERY = lambda name, api_key : '''
 COMPANY_QUERY = lambda cik, api_key : '''
     query {
         company(cik:"%s",apiKey : "%s"){
+            name
+            sic 
+            countryba
+            cityba
+            zipba 
+            bas1
+            bas2
+            baph
+            countryma
+            stprma
+            cityma
+            zipma
+            mas1
+            mas2
+            countryinc
+            stprinc
+            ein
+            former
+            changed
             income
             cash
             balance
+            equity
         }
     }'''%(cik,api_key)
 
@@ -51,7 +72,7 @@ def initialize():
     print('> 🏛️\twelcome to polity.')
 
 def initialized():
-    print('> 🌟\tauth success. apis connected')
+    print('> 🌟\tauth success. apis connected.')
 
 def failed():
     print('> ☠️\tclient failed to connect to api!')
